
% All programs in this collection are free software: 
% you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% Copyright 2007-2008 Alexander Zien.
% Max Planck Intitute for Biological Cybernetics, Tbingen, Germany.
% Friedrich Miescher Lab of the Max Planck Society, Tbingen, Germany.


%==============================================================================
function [ optParam ] = MP_getLicence( optParam, fieldName );
%==============================================================================


if( ~exist('fieldName','var') )
  fieldName = 'licence';
end;
optParam = setDefault( optParam, 'licence', [] );
optParam = setDefault( optParam, 'permanentLicence', [] );
ASSERT( isempty(optParam.licence) );
ASSERT( isempty(getfield(optParam,fieldName)) );
if( ~isempty(optParam.permanentLicence) )
  optParam.licence = optParam.permanentLicence;
  return;
end;


switch( optParam.optimizer )
  
%------------------------------------------------------------------------------
% --- matlab optimization toolbox
%------------------------------------------------------------------------------
 case 'toolbox'
  % nothing to do
  
%------------------------------------------------------------------------------
% --- CPLEX, using interface by Gunnar R"atsch
%------------------------------------------------------------------------------
 case 'cplexgun'
  optParam = setDefault( optParam, 'parallel', 1 );
  cplexEnv = cplex_license( 0, optParam.parallel );
  how = lp_set_param( cplexEnv, 'CPX_PARAM_THREADS', optParam.parallel, 1 );
  ASSERT( strcmp(how,'OK') );
  how = lp_set_param( cplexEnv, 'CPX_PARAM_BARORDER', 2, 1 );
  ASSERT( strcmp(how,'OK') );
  optParam = setfield( optParam, fieldName, cplexEnv );
  
%------------------------------------------------------------------------------
% --- CPLEX, with cplexint interface (http://control.ee.ethz.ch/~hybrid/cplexint.php)
%------------------------------------------------------------------------------
 case 'cplexint'
  % nothing to do
  
 otherwise
  error( 'unknown optimizer' );
end;

